==> sveltefirets-0.0.20.tgz: package/client/firestore-lite.js <==
// Use when wanting to receive back promises that will resolve or error when internet is flaky, unlike regular firestore methods which won't resolve right away in these situations. See notes in Readme.md for more info.
import { collection, doc, getDoc, addDoc, setDoc, deleteDoc, updateDoc, serverTimestamp, } from 'firebase/firestore/lite';
import { getDb } from './init';
import { getUid } from './uid';
function colRef(ref) {
    const db = getDb();
    return typeof ref === 'string' ? collection(db, ref) : ref;
}
function docRef(ref) {
    if (typeof ref === 'string') {
        const pathParts = ref.split('/');
        const documentId = pathParts.pop();
        const collectionString = pathParts.join('/');
        return doc(colRef(collectionString), documentId);
    }
    else {
        return ref;
    }
}
// not exporting lite versions of getCollection nor getDocument on client in favor of using full firestore cache-first versions.
async function getDocument(ref) {
    const docSnap = await getDoc(docRef(ref));
    return docSnap.exists() ? { ...docSnap.data(), id: docSnap.id } : null;
}
/**
 * Use when wanting to receive back promises that will resolve or error when internet is flaky, unlike regular firestore methods which won't resolve right away in these situations.
 * Be sure to import firestore methods such as serverTimestamp() from firebase/firestore/lite otherwise you will receive errors */
export function addOnline(ref, data, opts = {}) {
    return addDoc(colRef(ref), {
        ...data,
        [opts.abbreviate ? 'ca' : 'createdAt']: serverTimestamp(),
        [opts.abbreviate ? 'cb' : 'createdBy']: getUid(),
        [opts.abbreviate ? 'ua' : 'updatedAt']: serverTimestamp(),
        [opts.abbreviate ? 'ub' : 'updatedBy']: getUid(),
    });
}
/**
 * Use when wanting to receive back promises that will resolve or error when internet is flaky, unlike regular firestore methods which won't resolve right away in these situations.
 * Be sure to import firestore methods such as serverTimestamp() from firebase/firestore/lite otherwise you will receive errors */
export async function setOnline(ref, data, opts = {}) {
    const snap = await getDocument(ref);
    return await (snap
        ? updateOnline(ref, data)
        : setDoc(docRef(ref), {
            ...data,
            [opts.abbreviate ? 'ca' : 'createdAt']: serverTimestamp(),
            [opts.abbreviate ? 'cb' : 'createdBy']: getUid(),
            [opts.abbreviate ? 'ua' : 'updatedAt']: serverTimestamp(),
            [opts.abbreviate ? 'ub' : 'updatedBy']: getUid(),
        }, { merge: opts.merge }));
} // could split apart into set and upsert if desired, https://stackoverflow.com/questions/46597327/difference-between-set-with-merge-true-and-update
/**
 * Use when wanting to receive back promises that will resolve or error when internet is flaky, unlike regular firestore methods which won't resolve right away in these situations.
 * Be sure to import firestore methods such as serverTimestamp() from firebase/firestore/lite otherwise you will receive errors */
export async function updateOnline(ref, data, opts = {}) {
    // @ts-ignore
    return updateDoc(docRef(ref), {
        ...data,
        [opts.abbreviate ? 'ua' : 'updatedAt']: serverTimestamp(),
        [opts.abbreviate ? 'ub' : 'updatedBy']: getUid(),
    });
}
/**
 * Use when wanting to receive back promises that will resolve or error when internet is flaky, unlike regular firestore methods which won't resolve right away in these situations.
 * Be sure to import firestore methods such as serverTimestamp() from firebase/firestore/lite otherwise you will receive errors */
export function deleteDocumentOnline(ref) {
    return deleteDoc(docRef(ref));
}

==> sveltefirets-0.0.25.tgz: package/client/firestore-lite.js <==
// Use when wanting to receive back promises that will resolve or error when internet is flaky, unlike regular firestore methods which won't resolve right away in these situations. See notes in Readme.md for more info.
import { collection, doc, getDoc, addDoc, setDoc, deleteDoc, updateDoc, serverTimestamp, } from 'firebase/firestore/lite';
import { getDb } from './init';
import { getUid } from './uid';
function colRef(ref) {
    const db = getDb();
    return typeof ref === 'string' ? collection(db, ref) : ref;
}
function docRef(ref) {
    if (typeof ref === 'string') {
        const pathParts = ref.split('/');
        const documentId = pathParts.pop();
        const collectionString = pathParts.join('/');
        return doc(colRef(collectionString), documentId);
    }
    else {
        return ref;
    }
}
// not exporting lite versions of getCollection nor getDocument on client in favor of using full firestore cache-first versions.
async function getDocument(ref) {
    const docSnap = await getDoc(docRef(ref));
    return docSnap.exists() ? { ...docSnap.data(), id: docSnap.id } : null;
}
/**
 * Use when wanting to receive back promises that will resolve or error when internet is flaky, unlike regular firestore methods which won't resolve right away in these situations.
 * Be sure to import firestore methods such as serverTimestamp() from firebase/firestore/lite otherwise you will receive errors */
export function addOnline(ref, data, opts = {}) {
    data[opts.abbreviate ? 'ca' : 'createdAt'] = serverTimestamp();
    data[opts.abbreviate ? 'cb' : 'createdBy'] = getUid();
    data[opts.abbreviate ? 'ua' : 'updatedAt'] = serverTimestamp();
    data[opts.abbreviate ? 'ub' : 'updatedBy'] = getUid();
    return addDoc(colRef(ref), data);
}
/**
 * Use when wanting to receive back promises that will resolve or error when internet is flaky, unlike regular firestore methods which won't resolve right away in these situations.
 * Be sure to import firestore methods such as serverTimestamp() from firebase/firestore/lite otherwise you will receive errors */
export async function setOnline(ref, data, opts = {}) {
    const snap = await getDocument(ref);
    if (snap) {
        return await updateOnline(ref, data);
    }
    data[opts.abbreviate ? 'ca' : 'createdAt'] = serverTimestamp();
    data[opts.abbreviate ? 'cb' : 'createdBy'] = getUid();
    data[opts.abbreviate ? 'ua' : 'updatedAt'] = serverTimestamp();
    data[opts.abbreviate ? 'ub' : 'updatedBy'] = getUid();
    return await setDoc(docRef(ref), data, { merge: opts.merge });
} // could split apart into set and upsert if desired, https://stackoverflow.com/questions/46597327/difference-between-set-with-merge-true-and-update
/**
 * Use when wanting to receive back promises that will resolve or error when internet is flaky, unlike regular firestore methods which won't resolve right away in these situations.
 * Be sure to import firestore methods such as serverTimestamp() from firebase/firestore/lite otherwise you will receive errors */
export async function updateOnline(ref, data, opts = {}) {
    data[opts.abbreviate ? 'ua' : 'updatedAt'] = serverTimestamp();
    data[opts.abbreviate ? 'ub' : 'updatedBy'] = getUid();
    return updateDoc(docRef(ref), data);
}
/**
 * Use when wanting to receive back promises that will resolve or error when internet is flaky, unlike regular firestore methods which won't resolve right away in these situations.
 * Be sure to import firestore methods such as serverTimestamp() from firebase/firestore/lite otherwise you will receive errors */
export function deleteDocumentOnline(ref) {
    return deleteDoc(docRef(ref));
}
